@@ -30,6 +30,8 @@ function Leader(guiAction) {
     this.arrowHead = true;
     this.leaderEntity = undefined;
     this.segment = undefined;
+    this.arrowBlockId = RBlock.INVALID_ID;
+    this.lastPoint = undefined;
 
     this.setUiOptions("Leader.ui");
 }
@@ -135,6 +137,7 @@ Leader.prototype.pickCoordinate = function(event, preview) {
         if (!isNull(this.leaderEntity) && this.leaderEntity.countVertices()>0) {
             var appendPoint = this.leaderEntity.getEndPoint();
             this.segment = new RLine(appendPoint, point);
+            this.lastPoint = point;
 
             // append vertex:
             if (!preview) {
@@ -176,22 +179,40 @@ Leader.prototype.getOperation = function(preview) {
         if (this.leaderEntity.countVertices()>1) {
             var entity = new RLineEntity(this.getDocument(), new RLineData(this.segment));
             entity.copyAttributesFrom(this.leaderEntity.data());
+            this.initEntity(entity, preview);
             return new RAddObjectOperation(entity, false);
         }
         else {
             // for the first segment, we preview a real leader for the sake
             // of displaying the arrow correctly:
+            if (this.arrowBlockId!==RBlock.INVALID_ID) {
+                this.leaderEntity.setDimLeaderBlockId(this.arrowBlockId);
+            }
             var ld = this.leaderEntity.clone();
             ld.appendVertex(this.segment.getEndPoint());
             ld.setArrowHead(this.arrowHead);
-            return new RAddObjectOperation(ld, true, false);
+            this.initEntity(ld, preview);
+            return new RAddObjectOperation(ld, this.getUseCurrentAttributes(), false);
         }
     }
     else {
-        return new RAddObjectOperation(this.leaderEntity, this.getToolTitle(), true, false);
+        // add segment (not undoable as only adding the whole leader can be undone):
+        this.initEntity(this.leaderEntity, preview);
+        return new RAddObjectOperation(this.leaderEntity, this.getToolTitle(), this.getUseCurrentAttributes(), false);
     }
 };
 
+
+/**
+ * Can be overwritten to initialize the added entity.
+ */
+Leader.prototype.initEntity = function(entity, preview) {
+};
+
+Leader.prototype.getUseCurrentAttributes = function() {
+    return true;
+};
+
 /**
  * Updates the leader in storage and makes sure that this.leaderEntity
  * points to new new clone of the original entity.
@@ -265,10 +286,12 @@ Leader.prototype.updateButtonStates = function() {
     }
 
     var w = objectFromPath("MainWindow::Options::Undo");
-    if (this.leaderEntity.countVertices() > 1) {
-        w.enabled = true;
-    } else {
-        w.enabled = false;
+    if (!isNull(w)) {
+        if (this.leaderEntity.countVertices() > 1) {
+            w.enabled = true;
+        } else {
+            w.enabled = false;
+        }
     }
 };
 
