@@ -17,7 +17,7 @@
  * along with QCAD.
  */
 
-include("WidgetFactory.js");
+include("scripts/WidgetFactory.js");
 include("scripts/Widgets/OptionsToolBar/OptionsToolBar.js");
 
 if (RSettings.isGuiEnabled()) {
@@ -1646,8 +1646,16 @@ EAction.getScales = function(unit) {
                 '1" = 512"', '1" = 1024"', '1" = 2048"', '1" = 4096"',
                 '1/4096" = 1\'-0"', '1/2048" = 1\'-0"', '1/1024" = 1\'-0"',
                 '1/512" = 1\'-0"', '1/256" = 1\'-0"', '1/128" = 1\'-0"',
-                '1/64" = 1\'-0"', '1/32" = 1\'-0"', '1/16" = 1\'-0"',
-                '1/8" = 1\'-0"', '1/4" = 1\'-0"', '3/4" = 1\'-0"', '1/2" = 1\'-0"',
+                '1/64" = 1\'-0"', 
+                '1/32" = 1\'-0"', 
+                '1/16" = 1\'-0"',
+                '3/32" = 1\'-0"', 
+                '1/8" = 1\'-0"', 
+                '3/16" = 1\'-0"', 
+                '1/4" = 1\'-0"', 
+                '3/8" = 1\'-0"',
+                '1/2" = 1\'-0"',
+                '3/4" = 1\'-0"', 
                 '1" = 1\'-0"', '2" = 1\'-0"', '3" = 1\'-0"', '4" = 1\'-0"',
                 '5" = 1\'-0"', '6" = 1\'-0"', '7" = 1\'-0"', '8" = 1\'-0"',
                 '9" = 1\'-0"', '10" = 1\'-0"', '11" = 1\'-0"');
@@ -1766,6 +1774,13 @@ EAction.prototype.pickCoordinate = function(event, preview) {
  * Default implementation. Calls pickCoordinate(event, false)
  */
 EAction.prototype.coordinateEvent = function(event) {
+    // don't let invalid positions go through for most cases (this is overridden for DefaultAction):
+    var pos = event.getModelPosition();
+    if (!isValidVector(pos)) {
+        EAction.handleUserWarning(qsTr("Invalid position"));
+        return;
+    }
+
     this.pickCoordinate(event, false);
 };
 
@@ -2258,6 +2273,10 @@ EAction.warnNotLineArcCircle = function() {
     EAction.handleUserWarning(qsTr("Entity is not a line, arc or circle."));
 };
 
+EAction.warnNotLineArcSplineEllipseArcPolyline = function() {
+    EAction.handleUserWarning(qsTr("Entity is not a line, arc, spline, ellipse arc or polyline."));
+};
+
 EAction.warnNotArcCircleEllipse = function() {
     EAction.handleUserWarning(qsTr("Entity is not an arc, circle or ellipse."));
 };
